@@ -10,6 +10,7 @@ class CheckResult:  # pylint: disable=too-few-public-methods
         self,
         passed: bool,
         description: str,
+        json_info,
         diagnostic: str = "No diagnostic message available",
     ):
         """Construct a CheckResult.
@@ -18,10 +19,12 @@ class CheckResult:  # pylint: disable=too-few-public-methods
             passed: The passed or failed status of the check result. If true, indicates that the
                 check has passed.
             description: The description to use in output.
+            json_info: the overall information to be included in json output
             diagnostic: The message to use in output if the check has failed.
         """
         self.passed = passed
         self.description = description
+        self.json_info = json_info
         self.diagnostic = diagnostic
 
     def display_result(self, show_diagnostic: bool = False) -> str:
@@ -37,7 +40,7 @@ class CheckResult:  # pylint: disable=too-few-public-methods
         icon_color = "green" if self.passed else "red"
         message = f"[{icon_color}]{icon}[/]  {self.description}"
         if not self.passed and show_diagnostic:
-            message = f"[yellow]   → {self.diagnostic}"
+            message += f"\n[yellow]   → {self.diagnostic}"
         return message
 
     def __str__(self, show_diagnostic: bool = False) -> str:
@@ -61,5 +64,5 @@ class CheckResult:  # pylint: disable=too-few-public-methods
             show_diagnostic: If true, show the diagnostic message if the check has failed.
                 Defaults to false.
         """
-        message = self.display_result()
+        message = self.display_result(show_diagnostic)
         rich.print(message)
